#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import sys

from mastodon_toot_follower import mastodon_util
from mastodon_toot_follower.app import App
from mastodon_toot_follower.conversation.conversation import Conversation


def main():
    if len(sys.argv) != 2:
        usage()
    toot_url = sys.argv[1]

    try:
        instance_url, username, toot_id = mastodon_util.parse_toot_url(url=toot_url)
    except Exception as e:
        print(e, file=sys.stderr)
        usage()

    app = App()
    conversation = Conversation(app=app,
                                mastodon_instance=instance_url,
                                toot_id=toot_id)
    conversation.save_changes()

    print(f'Conversation length: {conversation.conversation_length()}')
    print(f'Conversation updates:\n')
    print('\n'.join([str(update) for update in conversation.new_updates]))


def usage():
    print(f'\n'
          f'usage: {sys.argv[0]} MASTODON_TOOT_URL\n'
          f'example: {sys.argv[0]} https://mastodon.instance/@user@another.instance/123456', file=sys.stderr)
    exit(1)


if __name__ == '__main__':
    main()
