#!/usr/bin/env python3
# -*- coding: utf-8 -*-
from enum import Enum

from flask import Flask, Response, render_template
from flask import request

from mastodon_toot_follower import mastodon_util, path_util
from mastodon_toot_follower.app import App as MastodonApp
from mastodon_toot_follower.conversation.conversation import Conversation

# Create Flask's `app` object
app = Flask(
    __name__,
    instance_relative_config=False,
    template_folder=str(path_util.get_templates_dir()),
    static_folder=str(path_util.get_static_dir()),
)

mastodon_app = MastodonApp()


class Templates(Enum):
    index = 'index.html'
    updates = 'updates.html'


@app.route('/', methods=['GET'])
def hello_world():
    return render_template(Templates.index.value)


@app.route('/rss/')
def rss():
    url = request.args.get('url', 'None')
    instance_url, username, toot_id = mastodon_util.parse_toot_url(url=url)

    conversation = Conversation(app=mastodon_app, mastodon_instance=instance_url, toot_id=toot_id)
    conversation.save_changes()

    fg = conversation.as_feed(request.url)
    return Response(fg.rss_str(), mimetype='application/rss+xml')


@app.route('/html/<string:seed>/')
def html(seed: str):
    url = request.args.get('url', 'None')
    instance_url, username, toot_id = mastodon_util.parse_toot_url(url=url)

    conversation = Conversation(app=mastodon_app, mastodon_instance=instance_url, toot_id=toot_id, seed=seed)
    conversation.save_changes()

    return render_template(Templates.updates.value, updates=conversation.new_updates)


@app.route('/json/<string:seed>/')
def json(seed: str):
    url = request.args.get('url', 'None')
    instance_url, username, toot_id = mastodon_util.parse_toot_url(url=url)

    conversation = Conversation(app=mastodon_app, mastodon_instance=instance_url, toot_id=toot_id, seed=seed)
    conversation.save_changes()

    # If you return a dict or list from a view, it will be converted to a JSON response.
    return [update.dict for update in conversation.new_updates]


if __name__ == '__main__':
    app.run(host='0.0.0.0', port=5000)
